module.exports = function (grunt) {

	var backendModules = [];
	var tecfood = {
		js: ["./assets/js/services/**/*.js", "./assets/js/controllers/**/*.js", "!./assets/js/libs.js", "!./assets/js/engine.js", "!./assets/js/environment.js", "!./assets/js/app.js", "!./assets/js/app.min.js"],
		css: ["./assets/css/**/*.css", "!./assets/css/app.css", "!./assets/css/app.min.css"],
		libs: [
			"./bower_components/zh-cache-bypass/src/CacheBypass.js",
			"./bower_components/zh-preferences/dist/preferences.js",
			"./bower_components/zh-filter-preferences/dist/filter-preferences.js",
			"./bower_components/zh-layout-preferences/dist/layout-preferences.js",
			"./bower_components/zh-grid-configuration/dist/zh-grid-configuration.js",
			"./bower_components/zh-view-preferences/dist/view-preferences.js",
			"./bower_components/zh-interval-component/dist/zh-interval-component.js",
			"./bower_components/zh-grid-navigation/dist/GridNavigationLibrary.js",
			"./bower_components/zh-reports/dist/zhReports.js",
			"./bower_components/zhuaclfrontend/assets/dist/main.js",
			"./bower_components/zhulog/dist/main.js",
			"./bower_components/tek-libraries/dist/main.js",
			'./bower_components/zh-image-uploader/dist/zh-image-uploader.js',
			'./bower_components/zh-select-autocomplete/dist/zh-select-autocomplete.js',
			"./assets/js/libraries/QRCodeGenerator.js"
		]
	};

	grunt.initConfig({
		concat: {
			js: {
				options: {
					process: function(src, filepath) {
						return "// FILE: " + filepath + "\n" + src + "\n";
					}
				},
				src: tecfood.js,
				dest: "assets/js/app.js"
			},
			libs: {
				options: {
					process: function(src, filepath) {
						return "// FILE: " + filepath + "\n" + src + "\n";
					}
				},
				src: tecfood.libs,
				dest: "assets/js/libs.js"
			},
			css: {
				options: {
					process: function(src, filepath) {
						return "/* FILE: " + filepath + " */\n" + src + "\n";
					}
				},
				src: tecfood.css,
				dest: "assets/css/app.css"
			}
		},
		uglify: {
			options: {
				mangle: false,
				compress: false,
				report: "min",
				// the banner is inserted at the top of the output
				banner: '/*! <%= grunt.template.today("dd-mm-yyyy") %> */\n'
			},
			dist: {
				files: {
					"assets/js/app.min.js": tecfood.js
				}
			}
		},
		jshint: {
			all: tecfood.js.concat(["GruntFile.js"]),
			options: {
				evil: true,
				esversion: 6
			}
		},
		watch: {
			js: {
				files: tecfood.js.concat(["GruntFile.js"]),
				tasks: ["jshint", "concat:js"]
			},
			css: {
				files: tecfood.css,
				tasks: ["concat:css"]
			}
		},
		cssmin: {
			dist: {
				src: tecfood.css,
				dest: "assets/css/app.min.css"
			}
		},
		// NÂO COLOCAR PROPRIEDADE PARA SUBSTIUIR IDS
		zhIdGenerator: {
			options: {
				jsonPath: ["./assets/json"],
				menuPath: ["./assets/json/menu.json"]
			}
		},
		buildAclStruct: {
			options: {
				menuConfigFile: "./menuConfig.json"
			}
		},
		buildEnvironment: {
			development: {
				configFile: "./config/devEnvironment.json"
			},
			production: {
				configFile: "./config/prodEnvironment.json"
			},
			test: {
				configFile: "./config/testEnvironment.json"
			},
			srcFolders: ["../backend/reports/", "../backend/config/", "./assets/js", "./assets/json", "./config", "./", "./assets"]
		},
		zhWords: {
			options: {
				serverUrl: "https://rc-translate.teknisa.com/backend/index.php",
				organization: "20",
				project: "2229"
			}
		}
	});

	grunt.loadNpmTasks('grunt-contrib-jshint');
	grunt.loadNpmTasks('grunt-contrib-uglify');
	grunt.loadNpmTasks('grunt-contrib-concat');
	grunt.loadNpmTasks('grunt-contrib-watch');
	grunt.loadNpmTasks('grunt-contrib-cssmin');
	grunt.loadNpmTasks('grunt-zh-id-generator');
    grunt.loadNpmTasks('grunt-zhuacl-structure');
	grunt.loadNpmTasks('grunt-zh-environment-builder');
	grunt.loadNpmTasks("grunt-zh-words");

	grunt.registerTask('default', ['jshint', 'concat', 'buildAclStruct', 'buildEnvironment']);
	grunt.registerTask('mergeBranch', ['zhIdGenerator', 'buildAclStruct']);
	grunt.registerTask('final', ['cssmin', 'uglify']);
};
